Changelog
=========

v2.0.1
------

  * Fix Travis build testing

v2.0.0
------

  * Upgrade to Django 1.8
  * Add django rest framework to default kit
  * Change out the base templates to use materialize and no framework by default

v1.0.2
------

  * Adding a placeholder file so we create a static directory
  * Fixing makefile so renaming works on Macs

v1.0.1
------

  * Adding a license file
  * Adding a default custom user model
  * Including travis badge in project by default
  * Cleaning up requirements file

v1.0.0
------

  * Initial release
